@@ -1,9 +1,9 @@
-'''
+"""
 Copyright (C) Optumi Inc - All rights reserved.
 
 You may only use this code under license with Optumi Inc and any distribution or modification is strictly prohibited.
 To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
-'''
+"""
 
 import json
 from pathlib import Path
@@ -15,21 +15,16 @@ HERE = Path(__file__).parent.resolve()
 with (HERE / "labextension" / "package.json").open() as fid:
     data = json.load(fid)
 
-def _jupyter_labextension_paths():
-    return [{
-        "src": "labextension",
-        "dest": data["name"]
-    }]
 
+def _jupyter_labextension_paths():
+    return [{"src": "labextension", "dest": data["name"]}]
 
 
 from .handlers import setup_handlers
 
 
 def _jupyter_server_extension_points():
-    return [{
-        "module": "jupyterlab_optumi"
-    }]
+    return [{"module": "jupyterlab_optumi"}]
 
 
 def _load_jupyter_server_extension(server_app):
@@ -41,5 +36,8 @@ def _load_jupyter_server_extension(server_app):
         JupyterLab application instance
     """
     setup_handlers(server_app)
-    server_app.log.info("Registered jupyterlab-optumi extension version " + __version__ + " at URL path /optumi")
-
+    server_app.log.info(
+        "Registered jupyterlab-optumi extension version "
+        + __version__
+        + " at URL path /optumi"
+    )
